summaryrefslogtreecommitdiff
path: root/app/src
diff options
context:
space:
mode:
Diffstat (limited to 'app/src')
-rw-r--r--app/src/main/java/io/swagger/client/model/ModelsGateway.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/src/main/java/io/swagger/client/model/ModelsGateway.java b/app/src/main/java/io/swagger/client/model/ModelsGateway.java
index 3da72aa9..8c020eb1 100644
--- a/app/src/main/java/io/swagger/client/model/ModelsGateway.java
+++ b/app/src/main/java/io/swagger/client/model/ModelsGateway.java
@@ -273,10 +273,10 @@ public class ModelsGateway {
}
/**
* TCP, UDP or KCP. This was called \"protocol\" in previous versions of the API.
* @return transport
**/
- @ApiModelProperty(value = "TCP, UDP or KCP. This was called \"protocol\" in previous versions of the API.")
+ @ApiModelProperty(value = "TCP, UDP, KCP or Quic. This was called \"protocol\" in previous versions of the API.")
public String getTransport() {
return transport;
}
@@ -273,10 +273,10 @@ public class ModelsGateway {
}
/**
- * TCP, UDP or KCP. This was called \"protocol\" in previous versions of the API.
+ * TCP, UDP, KCP or Quic. This was called \"protocol\" in previous versions of the API.
* @return transport
**/